==> haskell-loop-0.3.0-248-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-loop.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 loop
version:              0.3.0
visibility:           public
id:                   loop-0.3.0-CPwMmvH6nYb1HhvgodkrM2
key:                  loop-0.3.0-CPwMmvH6nYb1HhvgodkrM2
license:              MIT
copyright:            2014 Niklas Hambüchen <mail@nh2.me>
maintainer:           Niklas Hambüchen <mail@nh2.me>
author:               Niklas Hambüchen <mail@nh2.me>
stability:            experimental
homepage:             https://github.com/nh2/loop
synopsis:             Fast loops (for when GHC can'\''t optimize forM_)
description:
    This package provides a convenient and fast alternative to the common
    `forM_ [1..n]` idiom, which in many cases GHC cannot fuse to efficient
    code.

    See <https://ghc.haskell.org/trac/ghc/ticket/8763>.

category:             Control
abi:                  f9dbefc616277fcb429896fd3632f45a
exposed:              True
exposed-modules:      Control.Loop Control.Loop.Internal
import-dirs:          /usr/lib/ghc-9.2.8/site-local/loop-0.3.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/loop-0.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-loop
hs-libraries:         HSloop-0.3.0-CPwMmvH6nYb1HhvgodkrM2
depends:              base-4.16.4.0
haddock-interfaces:   /usr/share/doc/haskell-loop/html/loop.haddock
haddock-html:         /usr/share/doc/haskell-loop/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-loop-0.3.0-276.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-loop.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 loop
version:              0.3.0
visibility:           public
id:                   loop-0.3.0-2hOExEIrcINFnhCyb3rfUL
key:                  loop-0.3.0-2hOExEIrcINFnhCyb3rfUL
license:              MIT
copyright:            2014 Niklas Hambüchen <mail@nh2.me>
maintainer:           Niklas Hambüchen <mail@nh2.me>
author:               Niklas Hambüchen <mail@nh2.me>
stability:            experimental
homepage:             https://github.com/nh2/loop
synopsis:             Fast loops (for when GHC can'\''t optimize forM_)
description:
    This package provides a convenient and fast alternative to the common
    `forM_ [1..n]` idiom, which in many cases GHC cannot fuse to efficient
    code.

    See <https://ghc.haskell.org/trac/ghc/ticket/8763>.

category:             Control
abi:                  4c6b68c0cba21dd1252f6f6191a4d164
exposed:              True
exposed-modules:      Control.Loop Control.Loop.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/loop-0.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/loop-0.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/loop-0.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-loop
hs-libraries:         HSloop-0.3.0-2hOExEIrcINFnhCyb3rfUL
depends:              base-4.17.2.1
haddock-interfaces:   /usr/share/doc/haskell-loop/html/loop.haddock
haddock-html:         /usr/share/doc/haskell-loop/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
